| print.wdsmatch | R Documentation |
Print method for wdsmatch objects
## S3 method for class 'wdsmatch'
print(x, digits = 4, ...)
x |
A |
digits |
Number of decimal places. |
... |
Additional arguments (ignored). |
Invisibly returns the input object x. Called for its
side effect of printing a formatted summary to the console, including
the point estimate, standard error, confidence interval, number of
matches, and sample sizes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.